SystemOrganization addCategory: #'PassportKernel-Squeak'!

ResourcePathFacade subclass: #SqueakFilenamePathFacade
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PassportKernel-Squeak'!

!SqueakFilenamePathFacade methodsFor: 'conversion services' stamp: 'Alan Lovejoy 3/18/2006 03:37'!
constructNativeResourceIDFromResourcePath: aResourcePath
	"Answer whatever value the current Smalltalk execution environment canonically would use to name/identify the external/persistent/remote resouce (e.g, a file) referenced by <aResourcePath> (.e.g, a String in Squeak, a Filename in VisualWorks, etc.)"

	^aResourcePath asAbsolute printString



	! !

!SqueakFilenamePathFacade methodsFor: 'conversion services' stamp: 'Alan L. Lovejoy 3/27/2006 21:27'!
constructResourcePathFromNativeResourceID: aNativeResourceID 
	"Construct and answer a ResourcePath that identifies the same resource
	(e.g, a file) as does <aNativeResourceID> (where <aNativeResourceID> is
	an object canonically used by the host Smalltalk implementation to
	name/identify external/persistent/remote resources;) in most Smalltalk
	implementations such an object would be a String.)"

	"{SqueakFilenamePathFacade new constructResourcePathFromNativeResourceID: FileDirectory default pathName}"
	"{SqueakFilenamePathFacade new constructResourcePathFromNativeResourceID: FileDirectory default pathName, FileDirectory pathNameDelimiter asString, 'foo.txt'}"
	"{SqueakFilenamePathFacade new constructResourcePathFromNativeResourceID: 'c:\foo\bar.txt'}"
	"{SqueakFilenamePathFacade new constructResourcePathFromNativeResourceID: '\foo\bar.txt'}"
	"{SqueakFilenamePathFacade new constructResourcePathFromNativeResourceID: 'foo\bar.txt'}"
	"{SqueakFilenamePathFacade new constructResourcePathFromNativeResourceID: 'bar.txt'}"
	"{SqueakFilenamePathFacade new constructResourcePathFromNativeResourceID: '.\bar.txt'}"
	"{SqueakFilenamePathFacade new constructResourcePathFromNativeResourceID: '.'}"
	"{SqueakFilenamePathFacade new constructResourcePathFromNativeResourceID: ''}"

	| ns components |

	"FileDirectory 
		splitName: 'foo\bar.txt' 
		to: [:prefix :suffix | Array with: prefix with: suffix]."

	FileDirectory 
		splitName: aNativeResourceID 
		to: [:prefix :suffix | 
			prefix size = 0
				ifTrue:
					[ns := nil.
					((FileDirectory default isKindOf: MacFileDirectory)
						ifTrue: [suffix = ':']
						ifFalse: [suffix = '.'])
							ifTrue: [components := Array new]
							ifFalse: [components := suffix isEmpty ifTrue: [#()] ifFalse: [Array with: suffix]]]
					ifFalse: 
						[| directory isRelative root endsWithColon |
						isRelative := false.
						[directory := FileDirectory forFileName: aNativeResourceID] 
							on: Error 
							do: [:ex | "We assume the error is complaining that the pathname isn't absolute--which means it's a relative path!!"
								isRelative := true. 
								ex return].
						isRelative
							ifTrue:
								[ns := nil.
								components := UtilityFunction componentsFromString: aNativeResourceID separator: self pathnameSeparator]
							ifFalse:
								[components := directory pathParts.
								root := components first.
								endsWithColon := root last = $:.
								(endsWithColon or: 
									[FileDirectory default isKindOf:MacFileDirectory]) 
										ifTrue: 
											[ns := endsWithColon ifTrue: [root] ifFalse: [root , ':'].
											components := components copyFrom: 2 to: components size]
										ifFalse: [ns := self rootDirectoryMetavalueString].
								suffix size > 0 ifTrue: [components := components copyWith: suffix]]]].

	^(self newResourcePath)
		setHostname: #localhost;
		setNamespace: ns;
		setComponents: components;
		beImmutable! !

!SqueakFilenamePathFacade methodsFor: 'directory services' stamp: ''!
copyResource: sourceOperand to: destinationOperand
	"Copy the contents of the resource (e.g., a file) named/identified by <sourceOperand> to <destinationOperand>.  If the resource named/identified by <destinationOperand> does not exist, create it. If a resource so-named already exists, make it have exactly the same contents as the resource named/identified by <sourceNativeFileID>."

	| sourceStream targetStream buffer |
	sourceStream := self newExternalReadStream: sourceOperand type: #binary.
	[targetStream := self newExternalWriteStream: destinationOperand mode: #truncate check: false type: #binary.
	[buffer := String new: 50000.
	[sourceStream atEnd] whileFalse:
		[targetStream nextPutAll: (sourceStream nextInto: buffer)]] ensure: [targetStream close]] ensure: [sourceStream close].
! !

!SqueakFilenamePathFacade methodsFor: 'accessing' stamp: ''!
defaultDirectoryPathnameString
	"Answer a String that names/identifies the pathname of the external-file namespace relative to which non-absolute filenames will be interpreted.  In more conventional terminology, answer a String naming/identifying the actual full absolute pathname of the current default directory/folder.  It is acceptable, but not ideal, to answer a metavalue that serves as an indirect reference to the default directory (e.g., '.' on UNIX/Windows systems, and ':' on the Macintosh.) If not answering a metavalue, the answered String must start with the root directory of the current default volume/device (e.g., '/' on a Unix system, 'C:\' or 'D:\' (or whatever volume is the default) on a Windows system.)" 

	^FileDirectory default pathName! !

!SqueakFilenamePathFacade methodsFor: 'directory services' stamp: ''!
deleteResource: operand
	"Delete the resource (e.g., a file) named/identified by <operand>. If the resource named/identified by <operand> does not exist, raise an exception."

	| directory suffix |
	directory := FileDirectory forFileName: operand.
	suffix := FileDirectory localNameFor: operand.
	^(directory directoryExists: suffix)
		ifTrue: [(FileDirectory on: operand) recursiveDelete]
		ifFalse: [directory deleteFileNamed: suffix]
! !

!SqueakFilenamePathFacade methodsFor: 'accessing' stamp: ''!
fileExtensionSeparator
	"Answer the character that is used to separate file extensions from the rest of the file's name."

	^FileDirectory extensionDelimiter! !

!SqueakFilenamePathFacade methodsFor: 'directory services' stamp: ''!
makeDirectory: operand
	"Create a directory named <operand>. If the resource named/identified by <operand> already exists, raise an exception. A 'directory'  is a resource that serves as a namespace containing other resources."

	^(FileDirectory on: operand) assureExistence! !

!SqueakFilenamePathFacade methodsFor: 'directory services' stamp: ''!
moveResource: sourceOperand to: destinationOperand
	"Move the resource (e.g., a file) named/identified by <sourceOperand> to <destinationOperand>. If possible, implement the 'move' by removing and adding directory entries, instead of by actually copying the contents of the source resource. However, if that is not possible, then a) copy <sourceOperand> to <destinationOperand>, and then b) delete <sourceOperand>."

	| sourceDirectory targetDirectory | 
	sourceDirectory := FileDirectory forFileName: sourceOperand.
	targetDirectory := FileDirectory forFileName: destinationOperand.
	^sourceDirectory pathName = targetDirectory pathName
		ifTrue: [sourceDirectory rename: (FileDirectory localNameFor: sourceOperand) toBe: (FileDirectory localNameFor: destinationOperand)]
		ifFalse:
			[self copyResource: sourceOperand to: destinationOperand.
			self deleteResource: sourceOperand]

	

! !

!SqueakFilenamePathFacade methodsFor: 'stream creation' stamp: 'PaulDeBruicker 11/3/2011 08:41'!
newExternalReadStream: operand type: fileType
	"Synopsis

		Returns an external readStream that reads from the external data source with the given name.

	Specification (based on ANSI Smalltalk standard)

		Locate an external data source that is identified by the value of <operand>. The <operand> parameter is an instance of whatever class the host Smalltalk implementation would canonically use to identify an external data source (e.g., a Strring, a Filename, a URL, etc.)  If <operand> is a String (or if its content requires syntactical interpretation,) then its syntax is implementation-dependent.

		Return an object conforming to the ANSI <readFileStream> protocol whose future sequence values initially consist of the elements of the external data source and which initially has no past sequence values. The ordering of the sequence values is the same as the ordering within the external data source. The external data source serves as the stream backing store of the returned object. The value of <fileType> determines the external stream type and sequence value type of the result object.

	Parameters

		operand 		<readableString> 	identifies the external data source (typically, but not necessarily, a disk file)
		fileType		<symbol> 			an enumeration constant that specifies the type of the external data source, as defined by the ANSI Smalltalk standard

	Return Value

		<readFileStream> new

	Errors

		It is an error if the data source identified by <operand> does not exist, or if the user does not have read access permission"

	^(FileStream readOnlyFileNamed: operand) perform: fileType! !

!SqueakFilenamePathFacade methodsFor: 'stream creation' stamp: ''!
newExternalWriteStream: operand mode: mode check: enforceExistentialConstraint type: fileType
	"Synopsis

		Returns an external writeStream that writes to the external data source with the given name.

	Specification (based on ANSI Smalltalk standard)

		Depending upon the values of <enforceExistentialConstraint> and <mode>, either a) create a new external data source, or b) locate an existing external data source, which in either case is identified by the value of <operand>. The <operand> parameter is an instance of whatever class the host Smalltalk implementation would canonically use to identify an external data source (e.g., a Strring, a Filename, a URL, etc.)  If <operand> is a String (or if its content requires syntactical interpretation,) then its syntax is implementation-dependent.

		Return an object conforming to the ANSI Smalltalk <writeFileStream> protocol. The external data source serves as the stream backing store of the returned object. The returned object is a write-back stream. The value of <fileType> determines the external stream type and sequence value type of the result object.

		Valid values for <mode> are: #create, #append, and #truncate. The meaning of these values are:

				#create create a new external data source, with initial position at the beginning
				#append use an existing external data source, with initial position at its end
				#truncate use an existing external data source, initially truncating it.

		The value of <mode> determines the initial state of the past sequence values and future sequence values of the result object. If <mode> is #create or #truncate the past sequence values and future sequence values are both initially empty. If <mode> is #append the past sequence values initially consist of the elements of the external data source and future sequence values is initially empty. The ordering of the sequence values is the same as the ordering within the external data source. The <enforceExistentialConstraint> flag determines whether the data source specified by <operand> must exist or not exist.

		If <mode> = #create and <enforceExistentialConstraint> = false and the data source exists, then the existing file is used.
		If <mode> = #append and <enforceExistentialConstraint> = false and the data source does not exist, then it is created.
		If <mode> = #truncate and <enforceExistentialConstraint> = false and the data source  does not exist, then it is created.

		This operation is undefined if a value other than #create, #append or #truncate is used as the <mode> argument.

	Parameters

		operand 						<readableString> 	identifies the external data source (typically, but not necessarily, a disk file)
		mode 						<symbol> 			an enumeration constant that specifies the initial state of the external stream, as defined by the ANSI Smalltalk standard
		enforceExistentialConstraint 	<boolean> 			specifies whether or not the existence or non-existence of the data source identified by <operand> is an error
		fileType						<symbol> 			an enumeration constant that specifies the type of the external data source, as defined by the ANSI Smalltalk standard

	Return Value

		<writeFileStream> new

	Errors

		If <mode> = #create and <enforceExistentialConstraint> = true and the file exists.
		If <mode> = #append and <enforceExistentialConstraint> = true and the file does not exist.
		If <mode> = #truncate and <enforceExistentialConstraint> = true and the file does not exist.
		If the user does not have write permissions for the external data source.
		If the user does not have creation permissions for an external data source that is to be created."

	^(enforceExistentialConstraint 
		ifTrue: 
			[mode == #truncate
				ifTrue: 
					[(self resourceExists: operand) ifFalse: [^self signalError: 'File must exist in order to be truncated.'].
					FileStream forceNewFileNamed: operand]
				ifFalse:
					[mode == #create
						ifTrue: [FileStream newFileNamed: operand]
						ifFalse: [FileStream oldFileNamed: operand]]]
		ifFalse: 
			[mode == #truncate 
				ifTrue: [FileStream forceNewFileNamed: operand] 
				ifFalse: [FileStream fileNamed: operand]]) 
					perform: fileType! !

!SqueakFilenamePathFacade methodsFor: 'accessing' stamp: ''!
pathnameSeparator
	"Answer the character that is used to separate file pathname components (in other words, the directory separator character.)"

	^FileDirectory pathNameDelimiter! !

!SqueakFilenamePathFacade methodsFor: 'directory services' stamp: ''!
renameResource: originalOperand to: newOperand
	"Rename the resource (e.g., a file) named/identified by <originalOperand> to <newOperand>"

	^self moveResource: originalOperand to: newOperand! !

!SqueakFilenamePathFacade methodsFor: 'directory services' stamp: ''!
resourceExists: operand
	"Answer whether the resource (e.g., a file) named/identified by <operand> exists"

	| directory |
	directory := FileDirectory forFileName: operand.
	^directory exists and: [directory fileOrDirectoryExists: (FileDirectory localNameFor: operand)]! !

!SqueakFilenamePathFacade methodsFor: 'directory services' stamp: ''!
resourceIsDirectory: operand
	"Answer whether the resource (e.g., a file) named/identified by <operand> is a directory.  A resource is a directory if it acts as a namespace containing other resources."

	| directory |
	directory := FileDirectory forFileName: operand.
	^directory exists and: [directory directoryExists: (FileDirectory localNameFor: operand)]! !

!SqueakFilenamePathFacade methodsFor: 'directory services' stamp: ''!
sizeOfResource: operand
	"Answer the size (in bytes) of the resource (e.g., a file) named/identified by <operand>"

	| directory |
	directory := FileDirectory forFileName: operand.
	directory exists ifFalse: [^0].
	^(directory entryAt: (FileDirectory localNameFor: operand) ifAbsent: [^0]) fileSize

! !

!SqueakFilenamePathFacade methodsFor: 'testing' stamp: ''!
syntaxPermitsHostname
	^false! !

!SqueakFilenamePathFacade methodsFor: 'directory services' stamp: ''!
withResourcePathsOfResourcesInDirectory: operand do: block1
	"For each external/persistent/remote resource (e.g., a file) contained by the resource directory named/identified by <operand>, evaluate the one-argument Block <block1> with an argument that is a ResourcePath (which see) naming/identifying the external/persistent/remote resource (e.g, a file.) If <operand> does not name/identify a directory, raise an exception."

	| rpDirectory |
	rpDirectory := self constructResourcePathFromNativeResourceID: operand.
	(FileDirectory on: operand) fileAndDirectoryNames do: [:suffix | block1 value: (rpDirectory appending: suffix)]! !

UrlPathFacade subclass: #SqueakUrlPathFacade
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PassportKernel-Squeak'!

SqueakUrlPathFacade subclass: #SqueakAbstractFileUrlFacade
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PassportKernel-Squeak'!

!SqueakAbstractFileUrlFacade methodsFor: 'testing' stamp: 'Alan Lovejoy 3/28/2006 20:32'!
syntaxPermitsUserCredentials
	^true! !

SqueakAbstractFileUrlFacade subclass: #SqueakFileUrlFacade
	instanceVariableNames: 'platformFacade'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PassportKernel-Squeak'!

!SqueakFileUrlFacade methodsFor: 'directory services' stamp: ''!
copyResource: sourceOperand to: destinationOperand 
	"Copy the contents of the resource (e.g., a file) named/identified by <sourceOperand> to <destinationOperand>.  If the resource named/identified by <destinationOperand> does not exist, create it. If a resource so-named already exists, make it have exactly the same contents as the resource named/identified by <sourceNativeFileID>."

	^self platformFacade copyResource: sourceOperand to: destinationOperand
	! !

!SqueakFileUrlFacade methodsFor: 'directory services' stamp: ''!
deleteResource: operand
	"Delete the resource (e.g., a file) named/identified by <operand>. If the resource named/identified by <operand> does not exist, raise an exception."

	^self platformFacade deleteResource: operand! !

!SqueakFileUrlFacade methodsFor: 'stream creation' stamp: ''!
newExternalReadStream: operand type: fileType
	"Synopsis

		Returns an external readStream that reads from the external data source with the given name.

	Specification (based on ANSI Smalltalk standard)

		Locate an external data source that is identified by the value of <operand>. The <operand> parameter is an instance of whatever class the host Smalltalk implementation would canonically use to identify an external data source (e.g., a Strring, a Filename, a URL, etc.)  If <operand> is a String (or if its content requires syntactical interpretation,) then its syntax is implementation-dependent.

		Return an object conforming to the ANSI <readFileStream> protocol whose future sequence values initially consist of the elements of the external data source and which initially has no past sequence values. The ordering of the sequence values is the same as the ordering within the external data source. The external data source serves as the stream backing store of the returned object. The value of <fileType> determines the external stream type and sequence value type of the result object.

	Parameters

		operand 		<readableString> 	identifies the external data source (typically, but not necessarily, a disk file)
		fileType		<symbol> 			an enumeration constant that specifies the type of the external data source, as defined by the ANSI Smalltalk standard

	Return Value

		<readFileStream> new

	Errors

		It is an error if the data source identified by <operand> does not exist, or if the user does not have read access permission"

	^self platformFacade newExternalReadStream: operand type: fileType! !

!SqueakFileUrlFacade methodsFor: 'stream creation' stamp: ''!
newExternalWriteStream: operand mode: mode check: enforceExistentialConstraint type: fileType
	"Synopsis

		Returns an external writeStream that writes to the external data source with the given name.

	Specification (based on ANSI Smalltalk standard)

		Depending upon the values of <enforceExistentialConstraint> and <mode>, either a) create a new external data source, or b) locate an existing external data source, which in either case is identified by the value of <operand>. The <operand> parameter is an instance of whatever class the host Smalltalk implementation would canonically use to identify an external data source (e.g., a Strring, a Filename, a URL, etc.)  If <operand> is a String (or if its content requires syntactical interpretation,) then its syntax is implementation-dependent.

		Return an object conforming to the ANSI Smalltalk <writeFileStream> protocol. The external data source serves as the stream backing store of the returned object. The returned object is a write-back stream. The value of <fileType> determines the external stream type and sequence value type of the result object.

		Valid values for <mode> are: #create, #append, and #truncate. The meaning of these values are:

				#create create a new external data source, with initial position at the beginning
				#append use an existing external data source, with initial position at its end
				#truncate use an existing external data source, initially truncating it.

		The value of <mode> determines the initial state of the past sequence values and future sequence values of the result object. If <mode> is #create or #truncate the past sequence values and future sequence values are both initially empty. If <mode> is #append the past sequence values initially consist of the elements of the external data source and future sequence values is initially empty. The ordering of the sequence values is the same as the ordering within the external data source. The <enforceExistentialConstraint> flag determines whether the data source specified by <operand> must exist or not exist.

		If <mode> = #create and <enforceExistentialConstraint> = false and the data source exists, then the existing file is used.
		If <mode> = #append and <enforceExistentialConstraint> = false and the data source does not exist, then it is created.
		If <mode> = #truncate and <enforceExistentialConstraint> = false and the data source  does not exist, then it is created.

		This operation is undefined if a value other than #create, #append or #truncate is used as the <mode> argument.

	Parameters

		operand 					<readableString> 	identifies the external data source (typically, but not necessarily, a disk file)
		mode 						<symbol> 			an enumeration constant that specifies the initial state of the external stream, as defined by the ANSI Smalltalk standard
		enforceExistentialConstraint 	<boolean> 			specifies whether or not the existence or non-existence of the data source identified by <operand> is an error
		fileType						<symbol> 			an enumeration constant that specifies the type of the external data source, as defined by the ANSI Smalltalk standard

	Return Value

		<writeFileStream> new

	Errors

		If <mode> = #create and <enforceExistentialConstraint> = true and the file exists.
		If <mode> = #append and <enforceExistentialConstraint> = true and the file does not exist.
		If <mode> = #truncate and <enforceExistentialConstraint> = true and the file does not exist.
		If the user does not have write permissions for the external data source.
		If the user does not have creation permissions for an external data source that is to be created."

	^self platformFacade newExternalWriteStream: operand mode: mode check: enforceExistentialConstraint type: fileType! !

!SqueakFileUrlFacade methodsFor: 'conversion services' stamp: ''!
operandFromResourcePath: aResourcePath
	| stream |
	stream := (String new: 64) writeStream.
	self platformFacade print: aResourcePath on: stream.
	^stream contents! !

!SqueakFileUrlFacade methodsFor: 'accessing' stamp: 'Alan Lovejoy 4/1/2006 22:41'!
platformFacade
	platformFacade == nil ifTrue: [platformFacade := self resourcePathContext facadeAt: #platform].
	^platformFacade! !

!SqueakFileUrlFacade methodsFor: 'accessing' stamp: 'Alan Lovejoy 3/28/2006 20:30'!
protocol
	^#file! !

!SqueakFileUrlFacade methodsFor: 'directory services' stamp: ''!
renameResource: originalOperand to: newOperand
	"Rename the resource (e.g., a file) named/identified by <originalOperand> to <newOperand>"

	^self platformFacade renameResource: originalOperand to: newOperand! !

!SqueakFileUrlFacade methodsFor: 'directory services' stamp: ''!
resourceExists: operand
	"Answer whether the resource (e.g., a file) named/identified by <operand> exists"
	
	^self platformFacade resourceExists: operand

	! !

!SqueakFileUrlFacade methodsFor: 'directory services' stamp: ''!
resourceIsDirectory: operand
	"Answer whether the resource (e.g., a file) named/identified by <operand> is a directory.  A resource is a directory if it acts as a namespace containing other resources."

	^self platformFacade resourceIsDirectory: operand! !

!SqueakFileUrlFacade methodsFor: 'directory services' stamp: ''!
sizeOfResource: operand
	"Answer the size (in bytes) of the resource (e.g., a file) named/identified by <operand>"

	^self platformFacade sizeOfResource: operand! !

!SqueakFileUrlFacade methodsFor: 'testing' stamp: 'Alan Lovejoy 3/28/2006 20:32'!
syntaxPermitsPort
	^false! !

!SqueakFileUrlFacade methodsFor: 'directory services' stamp: ''!
withResourcePathsOfResourcesInDirectory: operand do: block1
	"For each external/persistent/remote resource (e.g., a file) contained by the resource directory named/identified by <operand>, evaluate the one-argument Block <block1> with an argument that is a ResourcePath (which see) naming/identifying the external/persistent/remote resource (e.g, a file.) If <operand> does not name/identify a directory, raise an exception."

	^self platformFacade withResourcePathsOfResourcesInDirectory: operand do: block1! !

SqueakUrlPathFacade subclass: #SqueakHttpUrlFacade
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PassportKernel-Squeak'!

!SqueakHttpUrlFacade methodsFor: 'private' stamp: ''!
configureRequest: anHttpRequest for: aResourcePath

	anHttpRequest resourcePath: aResourcePath.
	(HTTPSocket shouldUseProxy: aResourcePath hostname)
		ifTrue: [anHttpRequest proxy: (NetworkCorrespondent hostname: HTTPSocket httpProxyServer port: HTTPSocket httpProxyPort)].
	^anHttpRequest
	! !

!SqueakHttpUrlFacade methodsFor: 'stream creation' stamp: ''!
newExternalReadStream: operand type: fileType 
	"Synopsis

		Returns an external readStream that reads from the external data source with the given name.

	Specification (based on ANSI Smalltalk standard)

		Locate an external data source that is identified by the value of <operand>. The <operand> parameter is an instance of whatever class the host Smalltalk implementation would canonically use to identify an external data source (e.g., a Strring, a Filename, a URL, etc.)  If <operand> is a String (or if its content requires syntactical interpretation,) then its syntax is implementation-dependent.

		Return an object conforming to the ANSI <readFileStream> protocol whose future sequence values initially consist of the elements of the external data source and which initially has no past sequence values. The ordering of the sequence values is the same as the ordering within the external data source. The external data source serves as the stream backing store of the returned object. The value of <fileType> determines the external stream type and sequence value type of the result object.

	Parameters

		operand 	<readableString> 	identifies the external data source (typically, but not necessarily, a disk file)
		fileType		<symbol> 			an enumeration constant that specifies the type of the external data source, as defined by the ANSI Smalltalk standard

	Return Value

		<readFileStream> new

	Errors

		It is an error if the data source identified by <operand> does not exist, or if the user does not have read access permission"
		
	^(self configureRequest: HttpGetRequest new for: operand) responseFromServer readStream
! !

!SqueakHttpUrlFacade methodsFor: 'conversion services' stamp: ''!
operandFromResourcePath: aResourcePath
	^aResourcePath withoutFragment! !

!SqueakHttpUrlFacade methodsFor: 'accessing' stamp: 'Alan Lovejoy 3/28/2006 20:30'!
protocol
	^#http! !

!SqueakHttpUrlFacade methodsFor: 'directory services' stamp: ''!
resourceExists: operand
	"Answer whether the resource (e.g., a file) named/identified by <operand> exists"

	| request |
	request := self configureRequest: HttpHeadRequest new for: operand.
	^(request basicResponseFromServer) isError not
! !

!SqueakHttpUrlFacade methodsFor: 'directory services' stamp: ''!
sizeOfResource: operand
	"Answer the size (in bytes) of the resource (e.g., a file) named/identified by <operand>"
	
	| request response |
	request := self configureRequest: HttpHeadRequest new for: operand.
	response := request responseFromServer.
	^response contentLength


	! !

!SqueakHttpUrlFacade methodsFor: 'testing' stamp: 'Alan Lovejoy 3/28/2006 20:33'!
syntaxPermitsFragment
	^true! !

!SqueakHttpUrlFacade methodsFor: 'testing' stamp: 'Alan Lovejoy 3/28/2006 20:33'!
syntaxPermitsQueryString
	^true! !

!SqueakUrlPathFacade methodsFor: 'conversion services' stamp: ''!
constructNativeResourceIDFromString: aString
	"Answer whatever value the current Smalltalk execution environment canonically would use to name/identify the external/persistent/remote resource (e.g, a file) referenced by <aString> (.e.g, a String in Squeak, a Filename in VisualWorks, etc.)"
	
	^aString asUrl

	! !

!SqueakUrlPathFacade methodsFor: 'conversion services' stamp: ''!
constructResourcePathFromNativeResourceID: aNativeResourceID
	"Construct and answer a ResourcePath that identifies the same resource (e.g, a file) as does <aNativeResourceID> (where <aNativeResourceID> is an object canonically used by the host Smalltalk implementation to name/identify external/persistent/remote resources;) in most Smalltalk implementations such an object would be a String.)"

	^ResourcePath 
		fromString: aNativeResourceID toText 
		withContext: self resourcePathContext! !

!SqueakUrlPathFacade methodsFor: 'stream creation' stamp: ''!
newExternalWriteStream: operand mode: mode check: enforceExistentialConstraint type: fileType
	^self shouldNotImplement! !

Immutable subclass: #NetworkCorrespondent
	instanceVariableNames: 'hostname port'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PassportKernel-Squeak'!

!NetworkCorrespondent class methodsFor: 'instance creation' stamp: ''!
hostname: hostname port: port
	^self new
		setHostname: hostname;
		setPort: port;
		beImmutable! !

!NetworkCorrespondent methodsFor: 'stream creation' stamp: ''!
connectionStream
	Socket initializeNetwork.
	^SocketStream openConnectionToHostNamed: self hostname port: self port! !

!NetworkCorrespondent methodsFor: 'stream creation' stamp: 'Alan Lovejoy 3/31/2006 18:26'!
connectionStreamDo: block1
	| stream |
	stream := self connectionStream.
	^[block1 value: stream] ensure: [stream close]! !

!NetworkCorrespondent methodsFor: 'accessing' stamp: 'Alan Lovejoy 3/31/2006 12:49'!
hostname
	^hostname! !

!NetworkCorrespondent methodsFor: 'accessing' stamp: ''!
port
	^port! !

!NetworkCorrespondent methodsFor: 'initialize-release' stamp: ''!
setHostname: aHostname
	self assertMutability.
	hostname := aHostname == nil ifFalse: [aHostname asSymbol]! !

!NetworkCorrespondent methodsFor: 'initialize-release' stamp: ''!
setPort: portNumber
	self assertMutability.
	port := portNumber! !

EnvironmentFacade subclass: #SqueakEnvironmentFacade
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PassportKernel-Squeak'!

!SqueakEnvironmentFacade class methodsFor: 'private' stamp: 'Alan L. Lovejoy 3/27/2006 22:35'!
basicRegisterForStartupNotification
	"Make it so that whenever the Smalltalk image is restarted after a snapshot, the receiver will be sent the message #handleRestart.

	NOTE: This method is intended for use by image-based Smalltalk implementations.  It may or may not have any utility in the case of non-image-based Smalltalk systems."

	Smalltalk addToStartUpList: self! !

!SqueakEnvironmentFacade class methodsFor: 'private' stamp: 'Alan L. Lovejoy 3/27/2006 22:35'!
basicUnregisterForStartupNotification
	"Make it so that whenever the Smalltalk image is restarted after a snapshot, the receiver will NOT be sent the message #install (nor otherwise notified.)

	NOTE: This method is intended for use by image-based Smalltalk implementations.  It may or may not have any utility in the case of non-image-based Smalltalk systems."

	Smalltalk removeFromStartUpList: self! !

!SqueakEnvironmentFacade class methodsFor: 'class initialization' stamp: ''!
initialize
	"SqueakEnvironmentFacade initialize."

	| socketStreamClass systemDate |

	self registerForStartupNotification.

	"We add some methods to SocketStream programmatically because we need conditional compilation in order to be compatible with versions of Squeak both before and after version 3.9.  SocketStream was reimplemented de novo in 3.9."
	
	socketStreamClass := Smalltalk at: #SocketStream ifAbsent: [^self].
	systemDate := Date readFrom:  SystemVersion current date asString readStream.
	systemDate <= (Date newDay: 125 year: 2005)
		ifTrue: 
			[socketStreamClass
				compile: 
'position
	^self inStream position'
				classified: '*Passport-System-Squeak-stream in'.
				
			socketStreamClass
				compile: 
'peek
	self inStream atEnd 
		ifTrue: 
			[self isConnected ifFalse: [^nil].
			self receiveData.
			self atEnd ifTrue: [^nil]].
	^self inStream peek'
				classified: '*Passport-System-Squeak-stream in'.
				
			socketStreamClass
				compile: 
'skip: positionDelta
	self inStream skip: positionDelta'
				classified: '*Passport-System-Squeak-stream in']
		ifFalse: 
			[socketStreamClass
				compile: 
'position
	^lastRead'
				classified: '*Passport-System-Squeak-stream in'].
			
	ChangeSet current removeClassChanges: SocketStream "Ensure that the methods we've just added to SocketStream don't become part of the current ChangeSet."! !

!SqueakEnvironmentFacade class methodsFor: 'private' stamp: ''!
initializeResourcePathFacadeFactoryReferences

	"{EnvironmentFacade current initializeResourcePathFacadeFactoryReferences}"

	super initializeResourcePathFacadeFactoryReferences.
	ResourcePathFacadeFactoryReferences 
		at: #platform put: (Pathname components: #(#SqueakFilenamePathFacade)); 
		at: #http put: (Pathname components: #(#SqueakHttpUrlFacade)); 
		at: #file put: (Pathname components: #(#SqueakFileUrlFacade))! !

!SqueakEnvironmentFacade class methodsFor: 'accessing' stamp: 'Alan L. Lovejoy 3/27/2006 20:23'!
key
	^#Squeak! !

!SqueakEnvironmentFacade class methodsFor: 'object creation' stamp: 'PaulDeBruicker 3/9/2011 10:29'!
newWeakDictionary
	^WeakKeyDictionary new! !

!SqueakEnvironmentFacade class methodsFor: 'namespace operations' stamp: 'Alan L. Lovejoy 3/27/2006 20:16'!
purgeUnusedBindingsFromUndeclaredNamespace
	Undeclared removeUnreferencedKeys! !

!SqueakEnvironmentFacade class methodsFor: 'private' stamp: ''!
setPlatformClass
	self beCurrent! !

!SqueakEnvironmentFacade class methodsFor: 'image restart' stamp: 'Alan L. Lovejoy 3/27/2006 20:07'!
startUp
	self handleRestart! !

!SqueakEnvironmentFacade class methodsFor: 'accessing' stamp: 'Alan L. Lovejoy 3/27/2006 21:01'!
versionNumber
	"EnvironmentFacade current versionNumber"

	| stream major minor |
	stream := Smalltalk version readStream.
	UtilityFunction skipOver: stream until: [:ch | ch isDigit].
	major := stream upTo: $..
	minor := UtilityFunction nextFrom: stream while: [:ch | ch isDigit].
	^Pathname components: (Array with: major asNumber with: minor asNumber)! !
SqueakEnvironmentFacade initialize!
